@@ -2,7 +2,7 @@
 #
 # A simple example to install RStudio Desktop
 #
-# Copyright (C) 2014 - 2018  Carl Boettiger and Dirk Eddelbuettel
+# Copyright (C) 2014 - 2020  Carl Boettiger and Dirk Eddelbuettel
 #
 # Released under GPL (>= 2)
 #
@@ -15,7 +15,8 @@ suppressMessages(library(rvest))
 setwd("/tmp")                           # go to /tmp
 
 #url <- "https://dailies.rstudio.com/rstudioserver/oss/ubuntu/amd64/"
-url <- "https://dailies.rstudio.com/rstudioserver/oss/ubuntu/x86_64/"
+#url <- "https://dailies.rstudio.com/rstudioserver/oss/ubuntu/x86_64/"
+url <- "https://dailies.rstudio.com/rstudioserver/oss/bionic/x86_64/"
 pg <- read_html(url(url))
 tb <- html_table(html_nodes(pg, "table"))[[1]]
 file <- tb[1,1]
